Release History
===============

## 2.0.6
**Docs**
- Updated the readme

## 2.0.5
**Improvements**
- Removed list_all parameter since it was not useful (pip list does the job already)

**Bugfixes**
- Cleaned up ignore_list usage

## 2.0.4
**Bugfixes**
- Fixed default settings for boolean options

## 2.0.3
**Bugfixes**
- Fixed readme contents in `setup.py` for PyPI

## 2.0.0
**Improvements**
- Complete rewrite with large improvements
- Reliance on pip is removed and dependencies vendored


## 1.0.12
**Improvements**
- Add version command
- Small check optimization


## 1.0.11
**Improvements**
- Add check for duplicates in requirements and constraints files


## 1.0.10
**Bugfixes**
- Handle possible nonexistent requirement files and missing packages


## 1.0.9
**Improvements**
- Show all constraints that were not set to an exact version


## 1.0.8
**Documentation**
- Fix readme badges


## 1.0.7
**Documentation**
- Rename helper to utility


## 1.0.6
**Documentation**
- Add links to PyPi and license to readme


## 1.0.5
**Documentation**
- Remove changelog link


## 1.0.4
**Documentation**
- Replace history link in readme with file contents


## 1.0.3
**Documentation**
- Update package readme, metadata and changelog


## 1.0.2
**Documentation**
- Update library information.


## 1.0.1
**Bugfixes**
- Fix conflict check function call.


## 1.0.0
- Initial release
